@@ -1,11 +1,22 @@
-pickhandler<-function(i1=1, ppick=0, kzap="Y", err=NA, ycol=rgb(0,0,1) , NPX=1, WPX=WPX, NH)
+pickhandler<-function(i1=1, ppick=0, kzap="Y", err=NA, res=0, ycol=rgb(0,0,1) , pol=0, flg=0, onoff=1, NPX=1, WPX=WPX, NH=NH)
   {
 #######   used in PICK.GEN for handling picks
     if(missing(i1)) i1=1
     if(missing(kzap)) kzap="Y"
     if(missing(err)) err=NA
-     if(missing(ycol)) ycol=rgb(0,0,1)
+    if(missing(res)) res=NA
+    if(missing(ycol)) ycol=rgb(0,0,1)
+    if(missing(pol)) pol= 0
+    if(missing(flg)) flg= 0
+    if(missing(onoff)) onoff=1
     if(missing(NPX)) NPX=1
+
+    if(missing(NH))
+      {
+        print("Missing RSEIS (NH) list in pickhandler: need datetime")
+        return(NULL)
+      }
+    
     if(missing(WPX))
       {
         WPX = list(
@@ -31,9 +42,10 @@ pickhandler<-function(i1=1, ppick=0, kzap="Y", err=NA, ycol=rgb(0,0,1) , NPX=1,
       }
     
     ## print(i1)
+    
     asec = NH$info$sec[i1]+NH$info$msec[i1]/1000+NH$info$t1[i1]-NH$info$off[i1]+ppick
     pic1 = recdate(NH$info$jd[i1], NH$info$hr[i1], NH$info$mi[i1], asec)
-
+    
     WPX$tag[NPX]=paste(sep=".",NH$STNS[i1],  NH$COMPS[i1])
     WPX$name[NPX]=NH$STNS[i1]
     WPX$comp[NPX]=NH$COMPS[i1]
@@ -41,9 +53,9 @@ pickhandler<-function(i1=1, ppick=0, kzap="Y", err=NA, ycol=rgb(0,0,1) , NPX=1,
     WPX$phase[NPX]=kzap
     
     WPX$err[NPX]=err
-    WPX$pol[NPX]=0
-    WPX$flg[NPX]=0
-    WPX$res[NPX]=NA
+    WPX$pol[NPX]=pol
+    WPX$flg[NPX]=flg
+    WPX$res[NPX]= res
     WPX$yr[NPX]=NH$info$yr[i1]
     WPX$mo[NPX]= NH$info$mo[i1]
     WPX$dom[NPX]=NH$info$dom[i1]
@@ -52,7 +64,7 @@ pickhandler<-function(i1=1, ppick=0, kzap="Y", err=NA, ycol=rgb(0,0,1) , NPX=1,
     WPX$mi[NPX]=pic1$mi
     WPX$sec[NPX]=pic1$sec
     WPX$col[NPX]=ycol
-    WPX$onoff[NPX] = 1
+    WPX$onoff[NPX] = onoff
 
     return(WPX)
     
